summaryrefslogtreecommitdiffstats
path: root/tdecore/kglobalaccel_win.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/kglobalaccel_win.cpp')
-rw-r--r--tdecore/kglobalaccel_win.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/tdecore/kglobalaccel_win.cpp b/tdecore/kglobalaccel_win.cpp
index 8b0c81f1a..a6c80bc1a 100644
--- a/tdecore/kglobalaccel_win.cpp
+++ b/tdecore/kglobalaccel_win.cpp
@@ -136,7 +136,7 @@ bool KGlobalAccelPrivate::grabKey( const KKeyServer::Key& key, bool bGrab, KAcce
// We'll have to grab 8 key modifier combinations in order to cover all
// combinations of CapsLock, NumLock, ScrollLock.
// Does anyone with more X-savvy know how to set a mask on qt_xrootwin so that
// the irrelevant bits are always ignored and we can just make one XGrabKey
// call per accelerator? -- ellis
#ifndef NDEBUG
@@ -149,10 +149,10 @@ bool KGlobalAccelPrivate::grabKey( const KKeyServer::Key& key, bool bGrab, KAcce
sDebug += TQString("0x%3, ").arg(irrelevantBitsMask, 0, 16);
#endif
if( bGrab )
- XGrabKey( qt_xdisplay(), keyCodeX, keyModX | irrelevantBitsMask,
- qt_xrootwin(), True, GrabModeAsync, GrabModeSync );
+ XGrabKey( tqt_xdisplay(), keyCodeX, keyModX | irrelevantBitsMask,
+ tqt_xrootwin(), True, GrabModeAsync, GrabModeSync );
else
- XUngrabKey( qt_xdisplay(), keyCodeX, keyModX | irrelevantBitsMask, qt_xrootwin() );
+ XUngrabKey( tqt_xdisplay(), keyCodeX, keyModX | irrelevantBitsMask, tqt_xrootwin() );
}
}
#ifndef NDEBUG
@@ -169,7 +169,7 @@ bool KGlobalAccelPrivate::grabKey( const KKeyServer::Key& key, bool bGrab, KAcce
kdDebug(125) << "grab failed!\n";
for( uint m = 0; m <= 0xff; m++ ) {
if( m & keyModMaskX == 0 )
- XUngrabKey( qt_xdisplay(), keyCodeX, keyModX | m, qt_xrootwin() );
+ XUngrabKey( tqt_xdisplay(), keyCodeX, keyModX | m, tqt_xrootwin() );
}
}
}
@@ -222,8 +222,8 @@ bool KGlobalAccelPrivate::x11KeyPress( const XEvent *pEvent )
{
// do not change this line unless you really really know what you are doing (Matthias)
if ( !TQWidget::keyboardGrabber() && !TQApplication::activePopupWidget() ) {
- XUngrabKeyboard( qt_xdisplay(), pEvent->xkey.time );
- XFlush( qt_xdisplay()); // avoid X(?) bug
+ XUngrabKeyboard( tqt_xdisplay(), pEvent->xkey.time );
+ XFlush( tqt_xdisplay()); // avoid X(?) bug
}
if( !m_bEnabled )
@@ -237,7 +237,7 @@ bool KGlobalAccelPrivate::x11KeyPress( const XEvent *pEvent )
// e.g., KP_4 => Shift+KP_Left, and Shift+KP_4 => KP_Left.
if( pEvent->xkey.state & KKeyServer::modXNumLock() ) {
// TODO: what's the xor operator in c++?
- uint sym = XKeycodeToKeysym( qt_xdisplay(), codemod.code, 0 );
+ uint sym = XKeycodeToKeysym( tqt_xdisplay(), codemod.code, 0 );
// If this is a keypad key,
if( sym >= XK_KP_Space && sym <= XK_KP_9 ) {
switch( sym ) {
@@ -136,7 +136,7 @@ bool KGlobalAccelPrivate::grabKey( const KKeyServer::Key& key, bool bGrab, KAcce
// We'll have to grab 8 key modifier combinations in order to cover all
// combinations of CapsLock, NumLock, ScrollLock.
- // Does anyone with more X-savvy know how to set a mask on qt_xrootwin so that
+ // Does anyone with more X-savvy know how to set a mask on tqt_xrootwin so that
// the irrelevant bits are always ignored and we can just make one XGrabKey
// call per accelerator? -- ellis